@@ -26,11 +26,10 @@ import java.awt.image.BufferedImage;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.UnsupportedEncodingException;
 import java.util.List;
 import java.util.Map;
+import java.util.Vector;
 import java.util.concurrent.ExecutionException;
-import javax.imageio.ImageIO;
 import javax.swing.BoxLayout;
 import javax.swing.JComboBox;
 import javax.swing.JComponent;
@@ -146,8 +145,15 @@ public class StreamPane implements ActionListener
         }
 
         tabbedPane = new JTabbedPane();
-        tabbedPane.add("Text view", view.getStreamPanel());
-        tabbedPane.add("Hex view", hexView.getPane());
+        if (stream.isImage())
+        {
+            tabbedPane.add("Image view", view.getStreamPanel());
+        }
+        else
+        {
+            tabbedPane.add("Text view", view.getStreamPanel());
+            tabbedPane.add("Hex view", hexView.getPane());
+        }
 
         panel.add(tabbedPane);
     }
@@ -159,7 +165,7 @@ public class StreamPane implements ActionListener
 
     private JPanel createHeaderPanel(List<String> availableFilters, String i, ActionListener actionListener)
     {
-        JComboBox filters = new JComboBox(availableFilters.toArray());
+        JComboBox<String> filters = new JComboBox<String>(new Vector<String>(availableFilters));
         filters.setSelectedItem(i);
         filters.addActionListener(actionListener);
 
@@ -182,8 +188,13 @@ public class StreamPane implements ActionListener
                 if (currentFilter.equals(Stream.IMAGE))
                 {
                     requestImageShowing();
+                    tabbedPane.removeAll();
+                    tabbedPane.add("Image view", view.getStreamPanel());
                     return;
                 }
+                tabbedPane.removeAll();
+                tabbedPane.add("Text view", view.getStreamPanel());
+                tabbedPane.add("Hex view", hexView.getPane());
                 requestStreamText(currentFilter);
             }
             catch (IOException e)
@@ -208,13 +219,6 @@ public class StreamPane implements ActionListener
                 return;
             }
             view.showStreamImage(image);
-
-            ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            ImageIO.write(image, "jpg", baos);
-            baos.flush();
-            byte[] bytes = baos.toByteArray();
-            baos.close();
-            hexView.changeData(bytes);
         }
     }
 
