@@ -35,6 +35,7 @@ import java.util.List;
 import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.fontbox.ttf.TrueTypeFont;
 import org.apache.pdfbox.cos.COSArray;
 import org.apache.pdfbox.cos.COSBase;
 import org.apache.pdfbox.cos.COSDictionary;
@@ -145,7 +146,10 @@ public class PDDocument implements Closeable
     
     // fonts to subset before saving
     private final Set<PDFont> fontsToSubset = new HashSet<PDFont>();
-    
+
+    // fonts to close when closing document
+    private final Set<TrueTypeFont> fontsToClose = new HashSet<TrueTypeFont>();
+
     // Signature interface
     private SignatureInterface signInterface;
 
@@ -893,6 +897,18 @@ public class PDDocument implements Closeable
         return signatures;
     }
 
+    /**
+     * For internal PDFBox use when creating PDF documents: register a TrueTypeFont to make sure it
+     * is closed when the PDDocument is closed to avoid memory leaks. Users don't have to call this
+     * method, it is done by the appropriate PDFont classes.
+     *
+     * @param ttf
+     */
+    public void registerTrueTypeFontForClosing(TrueTypeFont ttf)
+    {
+        fontsToClose.add(ttf);
+    }
+
     /**
      * Returns the list of fonts which will be subset before the document is saved.
      */
@@ -1252,9 +1268,9 @@ public class PDDocument implements Closeable
 
     /**
      * This will save the document to an output stream.
-     * 
-     * @param output The stream to write to. It is recommended to wrap it in a
-     * {@link java.io.BufferedOutputStream}, unless it is already buffered.
+     *
+     * @param output The stream to write to. It will be closed when done. It is recommended to wrap
+     * it in a {@link java.io.BufferedOutputStream}, unless it is already buffered.
      *
      * @throws IOException if the output could not be written
      */
@@ -1288,7 +1304,8 @@ public class PDDocument implements Closeable
      * Save the PDF as an incremental update. This is only possible if the PDF was loaded from a
      * file or a stream, not if the document was created in PDFBox itself.
      *
-     * @param output stream to write. It should <i><b>not</b></i> point to the source file.
+     * @param output stream to write to. It will be closed when done. It should <i><b>not</b></i>
+     * point to the source file.
      * @throws IOException if the output could not be written
      * @throws IllegalStateException if the document was not loaded from a file or a stream.
      */
@@ -1344,7 +1361,8 @@ public class PDDocument implements Closeable
      * {@code PDDocument} instance and only AFTER {@link ExternalSigningSupport} instance is used.
      * </p>
      *
-     * @param output stream to write final PDF. It should <i><b>not</b></i> point to the source file.
+     * @param output stream to write the final PDF. It should <i><b>not</b></i> point to the source
+     * file. It will be closed when the document is closed.
      * @return instance to be used for external signing and setting CMS signature
      * @throws IOException if the output could not be written
      * @throws IllegalStateException if the document was not loaded from a file or a stream or
@@ -1380,9 +1398,13 @@ public class PDDocument implements Closeable
     }
 
     /**
-     * Returns the page at the given index.
+     * Returns the page at the given 0-based index.
+     * <p>
+     * This method is too slow to get all the pages from a large PDF document
+     * (1000 pages or more). For such documents, use the iterator of
+     * {@link PDDocument#getPages()} instead.
      *
-     * @param pageIndex the page index
+     * @param pageIndex the 0-based page index
      * @return the page at the given index.
      */
     public PDPage getPage(int pageIndex) // todo: REPLACE most calls to this method with BELOW method
@@ -1420,19 +1442,38 @@ public class PDDocument implements Closeable
     {
         if (!document.isClosed())
         {
+            // Make sure that:
+            // - first Exception is kept
+            // - all IO resources are closed
+            // - there's a way to see which errors occured
+
+            IOException firstException = null;
+
             // close resources and COSWriter
             if (signingSupport != null)
             {
-                signingSupport.close();
+                firstException = IOUtils.closeAndLogException(signingSupport, LOG, "SigningSupport", firstException);
             }
 
             // close all intermediate I/O streams
-            document.close();
+            firstException = IOUtils.closeAndLogException(document, LOG, "COSDocument", firstException);
             
             // close the source PDF stream, if we read from one
             if (pdfSource != null)
             {
-                pdfSource.close();
+                firstException = IOUtils.closeAndLogException(pdfSource, LOG, "RandomAccessRead pdfSource", firstException);
+            }
+
+            // close fonts
+            for (TrueTypeFont ttf : fontsToClose)
+            {
+                firstException = IOUtils.closeAndLogException(ttf, LOG, "TrueTypeFont", firstException);
+            }
+
+            // rethrow first exception to keep method contract
+            if (firstException != null)
+            {
+                throw firstException;
             }
         }
     }
