@@ -497,7 +497,8 @@ public final class PDPageContentStream implements Closeable
         // Unicode code points to keep when subsetting
         if (font.willBeSubset())
         {
-            for (int offset = 0; offset < text.length(); )
+            int offset = 0;
+            while (offset < text.length())
             {
                 int codePoint = text.codePointAt(offset);
                 font.addToSubset(codePoint);
@@ -979,6 +980,11 @@ public final class PDPageContentStream implements Closeable
      */
     public void transform(Matrix matrix) throws IOException
     {
+        if (inTextMode)
+        {
+            LOG.warn("Modifying the current transformation matrix is not allowed within text objects.");
+        }
+
         writeAffineTransform(matrix.createAffineTransform());
         writeOperator("cm");
     }
@@ -989,6 +995,11 @@ public final class PDPageContentStream implements Closeable
      */
     public void saveGraphicsState() throws IOException
     {
+        if (inTextMode)
+        {
+            LOG.warn("Saving the graphics state is not allowed within text objects.");
+        }
+
         if (!fontStack.isEmpty())
         {
             fontStack.push(fontStack.peek());
@@ -1010,6 +1021,11 @@ public final class PDPageContentStream implements Closeable
      */
     public void restoreGraphicsState() throws IOException
     {
+        if (inTextMode)
+        {
+            LOG.warn("Restoring the graphics state is not allowed within text objects.");
+        }
+
         if (!fontStack.isEmpty())
         {
             fontStack.pop();
@@ -2094,7 +2110,7 @@ public final class PDPageContentStream implements Closeable
     /**
      * Set line width to the given value.
      *
-     * @param lineWidth The width which is used for drwaing.
+     * @param lineWidth The width which is used for drawing.
      * @throws IOException If the content stream could not be written
      * @throws IllegalStateException If the method was called within a text block.
      */
@@ -2286,7 +2302,7 @@ public final class PDPageContentStream implements Closeable
      *
      * @param commands The commands to append to the stream.
      * @throws IOException If an error occurs while writing to the stream.
-     * @deprecated This method will be removed in a future release.
+     * @deprecated Usage of this method is discouraged.
      */
     @Deprecated
     public void appendRawCommands(String commands) throws IOException
@@ -2299,7 +2315,7 @@ public final class PDPageContentStream implements Closeable
      *
      * @param commands The commands to append to the stream.
      * @throws IOException If an error occurs while writing to the stream.
-     * @deprecated This method will be removed in a future release.
+     * @deprecated Usage of this method is discouraged.
      */
     @Deprecated
     public void appendRawCommands(byte[] commands) throws IOException
@@ -2312,7 +2328,7 @@ public final class PDPageContentStream implements Closeable
      *
      * @param data Append a raw byte to the stream.
      * @throws IOException If an error occurs while writing to the stream.
-     * @deprecated This method will be removed in a future release.
+     * @deprecated Usage of this method is discouraged.
      */
     @Deprecated
     public void appendRawCommands(int data) throws IOException
@@ -2325,7 +2341,7 @@ public final class PDPageContentStream implements Closeable
      *
      * @param data Append a formatted double value to the stream.
      * @throws IOException If an error occurs while writing to the stream.
-     * @deprecated This method will be removed in a future release.
+     * @deprecated Usage of this method is discouraged.
      */
     @Deprecated
     public void appendRawCommands(double data) throws IOException
@@ -2338,7 +2354,7 @@ public final class PDPageContentStream implements Closeable
      *
      * @param data Append a formatted float value to the stream.
      * @throws IOException If an error occurs while writing to the stream.
-     * @deprecated This method will be removed in a future release.
+     * @deprecated Usage of this method is discouraged.
      */
     @Deprecated
     public void appendRawCommands(float data) throws IOException
@@ -2351,7 +2367,7 @@ public final class PDPageContentStream implements Closeable
      *
      * @param name the name
      * @throws IOException If an error occurs while writing to the stream.
-     * @deprecated This method will be removed in a future release.
+     * @deprecated Usage of this method is discouraged.
      */
     @Deprecated
     public void appendCOSName(COSName name) throws IOException
@@ -2584,4 +2600,18 @@ public final class PDPageContentStream implements Closeable
         writeOperand(scale);
         writeOperator("Tz");
     }
+
+    /**
+     * Set the text rise value, i.e. move the baseline up or down. This is useful for drawing
+     * superscripts or subscripts.
+     *
+     * @param rise Specifies the distance, in unscaled text space units, to move the baseline up or
+     * down from its default location. 0 restores the default location.
+     * @throws IOException
+     */
+    public void setTextRise(float rise) throws IOException
+    {
+        writeOperand(rise);
+        writeOperator("Ts");
+    }
 }
