@@ -279,7 +279,7 @@ public class PDPageTree implements COSObjectable, Iterable<PDPage>
                     }
                 }
 
-                throw new IllegalStateException();
+                throw new IllegalStateException("Index not found: " + pageNum);
             }
             else
             {
@@ -294,7 +294,7 @@ public class PDPageTree implements COSObjectable, Iterable<PDPage>
             }
             else
             {
-                throw new IllegalStateException();
+                throw new IllegalStateException("Index not found: " + pageNum);
             }
         }
     }
